@@ -25,7 +25,8 @@
 #' @slot ptr External pointer to the underlying implementation
 #' @exportClass tiledb_domain
 setClass("tiledb_domain",
-         slots = list(ptr = "externalptr"))
+  slots = list(ptr = "externalptr")
+)
 
 tiledb_domain.from_ptr <- function(ptr) {
   stopifnot(`ptr must be a non-NULL externalptr to a tiledb_domain` = !missing(ptr) && is(ptr, "externalptr") && !is.null(ptr))
@@ -40,17 +41,21 @@ tiledb_domain.from_ptr <- function(ptr) {
 #' @param dims list() of tiledb_dim objects
 #' @return tiledb_domain
 #' @examples
-#' \dontshow{ctx <- tiledb_ctx(limitTileDBCores())}
-#' dom <- tiledb_domain(dims = c(tiledb_dim("d1", c(1L, 100L), type = "INT32"),
-#'                               tiledb_dim("d2", c(1L, 50L), type = "INT32")))
+#' \dontshow{
+#' ctx <- tiledb_ctx(limitTileDBCores())
+#' }
+#' dom <- tiledb_domain(dims = c(
+#'   tiledb_dim("d1", c(1L, 100L), type = "INT32"),
+#'   tiledb_dim("d2", c(1L, 50L), type = "INT32")
+#' ))
 #' @importFrom methods slot
 #' @importFrom methods new
 #' @export tiledb_domain
 tiledb_domain <- function(dims, ctx = tiledb_get_context()) {
   stopifnot(`Argument 'ctx' must be a tiledb_ctx object` = is(ctx, "tiledb_ctx"))
   is_dim <- function(obj) is(obj, "tiledb_dim")
-  if (is_dim(dims)) {                   # if a dim object given:
-    dims <- list(dims)                  # make it a vector so that lapply works below
+  if (is_dim(dims)) { # if a dim object given:
+    dims <- list(dims) # make it a vector so that lapply works below
   }
   if (missing(dims) || length(dims) == 0 || !all(vapply(dims, is_dim, logical(1)))) {
     stop("argument dims must be a list of one or more tileb_dim")
@@ -67,30 +72,37 @@ tiledb_domain <- function(dims, ctx = tiledb_get_context()) {
 #'
 #' @param object A domain object
 #' @export
-setMethod("raw_dump",
-          signature(object = "tiledb_domain"),
-          definition = function(object) libtiledb_domain_dump(object@ptr))
+setMethod(
+  "raw_dump",
+  signature(object = "tiledb_domain"),
+  definition = function(object) libtiledb_domain_dump(object@ptr)
+)
 
 # internal function returning text use here and in other higher-level show() methods
 .as_text_domain <- function(object) {
-    txt <- "tiledb_domain(c(\n"
-    dims <- dimensions(object)
-    nd <- length(dims)
-    for (i in seq_len(nd)) {
-        txt <- paste0(txt, "        ", .as_text_dimension(dims[[i]]),
-                      if (i == nd) "\n    ))" else ",\n")
-    }
-    txt
+  txt <- "tiledb_domain(c(\n"
+  dims <- dimensions(object)
+  nd <- length(dims)
+  for (i in seq_len(nd)) {
+    txt <- paste0(
+      txt, "        ", .as_text_dimension(dims[[i]]),
+      if (i == nd) "\n    ))" else ",\n"
+    )
+  }
+  txt
 }
 
 #' Prints a domain object
 #'
 #' @param object A domain object
 #' @export
-setMethod("show", "tiledb_domain",
-          definition = function(object) {
+setMethod(
+  "show",
+  "tiledb_domain",
+  definition = function(object) {
     cat(.as_text_domain(object), "\n")
-})
+  }
+)
 
 #' Returns a list of the tiledb_domain dimension objects
 #'
@@ -98,58 +110,79 @@ setMethod("show", "tiledb_domain",
 #' @param object tiledb_domain
 #' @return a list of tiledb_dim
 #' @examples
-#' \dontshow{ctx <- tiledb_ctx(limitTileDBCores())}
-#' dom <- tiledb_domain(dims = c(tiledb_dim("d1", c(1L, 100L), type = "INT32"),
-#'                               tiledb_dim("d2", c(1L, 50L), type = "INT32")))
+#' \dontshow{
+#' ctx <- tiledb_ctx(limitTileDBCores())
+#' }
+#' dom <- tiledb_domain(dims = c(
+#'   tiledb_dim("d1", c(1L, 100L), type = "INT32"),
+#'   tiledb_dim("d2", c(1L, 50L), type = "INT32")
+#' ))
 #' dimensions(dom)
 #'
 #' lapply(dimensions(dom), name)
 #'
 #' @export
-setMethod("dimensions", "tiledb_domain",
-          function(object) {
-            dim_ptrs <- libtiledb_domain_get_dimensions(object@ptr)
-            return(lapply(dim_ptrs, tiledb_dim.from_ptr))
-          })
+setMethod(
+  "dimensions",
+  "tiledb_domain",
+  function(object) {
+    dim_ptrs <- libtiledb_domain_get_dimensions(object@ptr)
+    return(lapply(dim_ptrs, tiledb_dim.from_ptr))
+  }
+)
 
 #' Returns the tiledb_domain TileDB type string
 #'
 #' @param object tiledb_domain
 #' @return tiledb_domain type string
 #' @examples
-#' \dontshow{ctx <- tiledb_ctx(limitTileDBCores())}
+#' \dontshow{
+#' ctx <- tiledb_ctx(limitTileDBCores())
+#' }
 #' dom <- tiledb_domain(dims = c(tiledb_dim("d1", c(1L, 100L), type = "INT32")))
 #' datatype(dom)
 #' dom <- tiledb_domain(dims = c(tiledb_dim("d1", c(0.5, 100.0), type = "FLOAT64")))
 #' datatype(dom)
 #'
 #' @export
-setMethod("datatype", "tiledb_domain",
-          function(object) {
-            ##return(libtiledb_domain_get_type(object@ptr))
-            #generalize from   domaintype <- libtiledb_domain_get_type(dom@ptr)   to
-            domaintype <- sapply(libtiledb_domain_get_dimensions(object@ptr),
-                                 libtiledb_dim_get_datatype)
-            return(domaintype)
-})
+setMethod(
+  "datatype",
+  "tiledb_domain",
+  function(object) {
+    ## return(libtiledb_domain_get_type(object@ptr))
+    # generalize from   domaintype <- libtiledb_domain_get_type(dom@ptr)   to
+    domaintype <- sapply(
+      libtiledb_domain_get_dimensions(object@ptr),
+      libtiledb_dim_get_datatype
+    )
+    return(domaintype)
+  }
+)
 
 #' Returns the number of dimensions of the `tiledb_domain`
 #'
 #' @param object tiledb_domain
 #' @return integer number of dimensions
 #' @examples
-#' \dontshow{ctx <- tiledb_ctx(limitTileDBCores())}
+#' \dontshow{
+#' ctx <- tiledb_ctx(limitTileDBCores())
+#' }
 #' dom <- tiledb_domain(dims = c(tiledb_dim("d1", c(0.5, 100.0), type = "FLOAT64")))
 #' tiledb_ndim(dom)
-#' dom <- tiledb_domain(dims = c(tiledb_dim("d1", c(0.5, 100.0), type = "FLOAT64"),
-#'                                    tiledb_dim("d2", c(0.5, 100.0), type = "FLOAT64")))
+#' dom <- tiledb_domain(dims = c(
+#'   tiledb_dim("d1", c(0.5, 100.0), type = "FLOAT64"),
+#'   tiledb_dim("d2", c(0.5, 100.0), type = "FLOAT64")
+#' ))
 #' tiledb_ndim(dom)
 #'
 #' @export
-setMethod("tiledb_ndim", "tiledb_domain",
-          function(object) {
-            return(libtiledb_domain_get_ndim(object@ptr))
-          })
+setMethod(
+  "tiledb_ndim", 
+  "tiledb_domain",
+  function(object) {
+    return(libtiledb_domain_get_ndim(object@ptr))
+  }
+)
 
 #' @rdname generics
 #' @export
@@ -160,19 +193,24 @@ setGeneric("is.integral", function(object) standardGeneric("is.integral"))
 #' @param object tiledb_domain
 #' @return TRUE if the domain is an integral domain, else FALSE
 #' @examples
-#' \dontshow{ctx <- tiledb_ctx(limitTileDBCores())}
+#' \dontshow{
+#' ctx <- tiledb_ctx(limitTileDBCores())
+#' }
 #' dom <- tiledb_domain(dims = c(tiledb_dim("d1", c(1L, 100L), type = "INT32")))
 #' is.integral(dom)
 #' dom <- tiledb_domain(dims = c(tiledb_dim("d1", c(0.5, 100.0), type = "FLOAT64")))
 #' is.integral(dom)
 #'
 #' @export
-setMethod("is.integral", "tiledb_domain",
-          function(object) {
-            dtype <- datatype(object)
-            res <- isTRUE(any(sapply(dtype, match, c("FLOAT32","FLOAT32"))))
-            return(!res)
-          })
+setMethod(
+  "is.integral",
+  "tiledb_domain",
+  function(object) {
+    dtype <- datatype(object)
+    res <- isTRUE(any(sapply(dtype, match, c("FLOAT32", "FLOAT32"))))
+    return(!res)
+  }
+)
 
 #' Retrieve the dimension (domain extent) of the domain
 #'
@@ -181,15 +219,19 @@ setMethod("is.integral", "tiledb_domain",
 #' @param x tiledb_domain
 #' @return dimension vector
 #' @examples
-#' \dontshow{ctx <- tiledb_ctx(limitTileDBCores())}
-#' dom <- tiledb_domain(dims = c(tiledb_dim("d1", c(1L, 100L), type = "INT32"),
-#'                               tiledb_dim("d2", c(1L, 100L), type = "INT32")))
+#' \dontshow{
+#' ctx <- tiledb_ctx(limitTileDBCores())
+#' }
+#' dom <- tiledb_domain(dims = c(
+#'   tiledb_dim("d1", c(1L, 100L), type = "INT32"),
+#'   tiledb_dim("d2", c(1L, 100L), type = "INT32")
+#' ))
 #' dim(dom)
 #'
 #' @export
 dim.tiledb_domain <- function(x) {
   dtype <- datatype(x)
-  if (isTRUE(any(sapply(dtype, match, c("FLOAT32","FLOAT64"))))) {
+  if (isTRUE(any(sapply(dtype, match, c("FLOAT32", "FLOAT64"))))) {
     stop("dim() is only defined for integral domains")
   }
   return(vapply(dimensions(x), dim, integer(1L)))
@@ -202,9 +244,11 @@ dim.tiledb_domain <- function(x) {
 #' @return TileDB Dimension object
 #' @export
 tiledb_domain_get_dimension_from_index <- function(domain, idx) {
-  stopifnot(`The 'domain' argument must be a tiledb_domain` = is(domain, "tiledb_domain"),
-            `The 'idx' argument must be numeric` = is.numeric(idx))
-  return(new("tiledb_dim", ptr=libtiledb_domain_get_dimension_from_index(domain@ptr, idx)))
+  stopifnot(
+    `The 'domain' argument must be a tiledb_domain` = is(domain, "tiledb_domain"),
+    `The 'idx' argument must be numeric` = is.numeric(idx)
+  )
+  return(new("tiledb_dim", ptr = libtiledb_domain_get_dimension_from_index(domain@ptr, idx)))
 }
 
 #' Returns a Dimension indicated by name for the given TileDB Domain
@@ -214,9 +258,11 @@ tiledb_domain_get_dimension_from_index <- function(domain, idx) {
 #' @return TileDB Dimension object
 #' @export
 tiledb_domain_get_dimension_from_name <- function(domain, name) {
-  stopifnot(`The 'domain' argument must be a tiledb_domain` = is(domain, "tiledb_domain"),
-            `The 'name' argument must be character` = is.character(name))
-  return(new("tiledb_dim", ptr=libtiledb_domain_get_dimension_from_name(domain@ptr, name)))
+  stopifnot(
+    `The 'domain' argument must be a tiledb_domain` = is(domain, "tiledb_domain"),
+    `The 'name' argument must be character` = is.character(name)
+  )
+  return(new("tiledb_dim", ptr = libtiledb_domain_get_dimension_from_name(domain@ptr, name)))
 }
 
 #' Check a domain for a given dimension name
@@ -226,7 +272,9 @@ tiledb_domain_get_dimension_from_name <- function(domain, name) {
 #' @return A boolean value indicating if the dimension exists in the domain
 #' @export
 tiledb_domain_has_dimension <- function(domain, name) {
-  stopifnot(`The 'domain' argument must be a tiledb_domain` = is(domain, "tiledb_domain"),
-            `The 'name' argument must be character` = is.character(name))
+  stopifnot(
+    `The 'domain' argument must be a tiledb_domain` = is(domain, "tiledb_domain"),
+    `The 'name' argument must be character` = is.character(name)
+  )
   libtiledb_domain_has_dimension(domain@ptr, name)
 }
