@@ -25,10 +25,11 @@
 #' @slot ptr An external pointer to the underlying implementation
 #' @exportClass tiledb_query
 setClass("tiledb_query",
-         slots = list(ptr = "externalptr"))
-         ##           arr = "ANY"))
-         ## could add arr of type 'ANY' (using shortcut to not have to deal with collate order)
-         ## if array was needed for query object
+  slots = list(ptr = "externalptr")
+)
+##           arr = "ANY"))
+## could add arr of type 'ANY' (using shortcut to not have to deal with collate order)
+## if array was needed for query object
 
 #' Creates a 'tiledb_query' object
 #'
@@ -38,12 +39,15 @@ setClass("tiledb_query",
 #' @param ctx (optional) A TileDB Ctx object
 #' @return 'tiledb_query' object
 #' @export tiledb_query
-tiledb_query <- function(array,
-                         type = if (tiledb_version(TRUE) >= "2.12.0")
-                                    c("READ", "WRITE", "DELETE", "MODIFY_EXCLUSIVE")
-                                else
-                                    c("READ", "WRITE"),
-                         ctx = tiledb_get_context()) {
+tiledb_query <- function(
+  array,
+  type = if (tiledb_version(TRUE) >= "2.12.0") {
+    c("READ", "WRITE", "DELETE", "MODIFY_EXCLUSIVE")
+  } else {
+    c("READ", "WRITE")
+  },
+  ctx = tiledb_get_context()
+) {
   stopifnot(`Argument 'arr' must be a tiledb_array object` = .isArray(array))
   type <- match.arg(type)
   array <- tiledb_array_open(array, type)
@@ -69,8 +73,13 @@ tiledb_query_type <- function(query) {
 #'   "COL_MAJOR", "ROW_MAJOR", "GLOBAL_ORDER", "UNORDERED")
 #' @return The modified query object, invisibly
 #' @export
-tiledb_query_set_layout <- function(query, layout=c("COL_MAJOR", "ROW_MAJOR",
-                                                    "GLOBAL_ORDER", "UNORDERED")) {
+tiledb_query_set_layout <- function(
+  query, 
+  layout = c(
+    "COL_MAJOR", "ROW_MAJOR",
+    "GLOBAL_ORDER", "UNORDERED"
+  )
+) {
   stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"))
   layout <- match.arg(layout)
   libtiledb_query_set_layout(query@ptr, layout)
@@ -117,16 +126,18 @@ tiledb_query_set_subarray <- function(query, subarray, type) {
 #' @return The modified query object, invisisibly
 #' @export
 tiledb_query_set_buffer <- function(query, attr, buffer) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'attr' must be character_variable` = is.character(attr),
-            `Argument 'buffer' must be integer, numeric or logical` = is.numeric(buffer) || is.logical(buffer))
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'attr' must be character_variable` = is.character(attr),
+    `Argument 'buffer' must be integer, numeric or logical` = is.numeric(buffer) || is.logical(buffer)
+  )
   if (is.numeric(buffer) || tiledb_version(TRUE) < "2.10.0") {
-      libtiledb_query_set_buffer(query@ptr, attr, buffer)
-  } else {              # logical now maps to BOOL which is a uint8_t, we need a different approach
-      nr <- NROW(buffer)
-      bufptr <- libtiledb_query_buffer_alloc_ptr("BOOL", nr, FALSE, 1)
-      bufptr <- libtiledb_query_buffer_assign_ptr(bufptr, "BOOL", buffer, FALSE)
-      query@ptr <- libtiledb_query_set_buffer_ptr(query@ptr, attr, bufptr)
+    libtiledb_query_set_buffer(query@ptr, attr, buffer)
+  } else { # logical now maps to BOOL which is a uint8_t, we need a different approach
+    nr <- NROW(buffer)
+    bufptr <- libtiledb_query_buffer_alloc_ptr("BOOL", nr, FALSE, 1)
+    bufptr <- libtiledb_query_buffer_assign_ptr(bufptr, "BOOL", buffer, FALSE)
+    query@ptr <- libtiledb_query_set_buffer_ptr(query@ptr, attr, bufptr)
   }
   invisible(query)
 }
@@ -138,8 +149,10 @@ tiledb_query_set_buffer <- function(query, attr, buffer) {
 #' @return An external pointer to the allocated buffer object
 #' @export
 tiledb_query_create_buffer_ptr_char <- function(query, varvec) {
-  stopifnot("Argument 'query' must be a tiledb_query object" = is(query, "tiledb_query"),
-            "Argument 'varvec' must be a character vector" = is.vector(varvec) && is.character(varvec))
+  stopifnot(
+    "Argument 'query' must be a tiledb_query object" = is(query, "tiledb_query"),
+    "Argument 'varvec' must be a character vector" = is.vector(varvec) && is.character(varvec)
+  )
   bufptr <- libtiledb_query_buffer_var_char_create(varvec, TRUE)
   bufptr
 }
@@ -151,9 +164,15 @@ tiledb_query_create_buffer_ptr_char <- function(query, varvec) {
 #' @param nullable An optional boolean indicating whether the column can have NULLs
 #' @return An external pointer to the allocated buffer object
 #' @export
-tiledb_query_alloc_buffer_ptr_char <- function(sizeoffsets, sizedata, nullable=FALSE) {
-  stopifnot(`Argument 'sizeoffset' must be numeric` = is.numeric(sizeoffsets),
-            `Argument 'sizedata' must be numeric` = is.numeric(sizedata))
+tiledb_query_alloc_buffer_ptr_char <- function(
+  sizeoffsets, 
+  sizedata, 
+  nullable = FALSE
+) {
+  stopifnot(
+    `Argument 'sizeoffset' must be numeric` = is.numeric(sizeoffsets),
+    `Argument 'sizedata' must be numeric` = is.numeric(sizedata)
+  )
   bufptr <- libtiledb_query_buffer_var_char_alloc_direct(sizeoffsets, sizedata, nullable)
   bufptr
 }
@@ -185,12 +204,13 @@ tiledb_query_alloc_buffer_ptr_char <- function(sizeoffsets, sizedata, nullable=F
 #' @return The modified query object, invisibly
 #' @export
 tiledb_query_set_buffer_ptr_char <- function(query, attr, bufptr) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'attr' must be a character object` = is.character(attr),
-            `Argument 'bufptr' must be an external pointer` = is(bufptr, "externalptr"))
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'attr' must be a character object` = is.character(attr),
+    `Argument 'bufptr' must be an external pointer` = is(bufptr, "externalptr")
+  )
   libtiledb_query_set_buffer_var_char(query@ptr, attr, bufptr)
   invisible(query)
-
 }
 
 #' Allocate a Query buffer for a given type
@@ -205,12 +225,20 @@ tiledb_query_set_buffer_ptr_char <- function(query, attr, bufptr) {
 #' default is one
 #' @return An external pointer to the allocated buffer object
 #' @export
-tiledb_query_buffer_alloc_ptr <- function(query, datatype, ncells, nullable=FALSE, varnum=1) {
-  stopifnot("Argument 'query' must be a tiledb_query object" = is(query, "tiledb_query"),
-            "Argument 'datatype' must be a character object" = is.character(datatype),
-            "Argument 'ncells' must be numeric" = is.numeric(ncells),
-            "Argument 'nullable' must be logical" = is.logical(nullable),
-            "Argument 'varnum' must be integer or numeric" = is.integer(varnum) || is.numeric(varnum))
+tiledb_query_buffer_alloc_ptr <- function(
+  query, 
+  datatype, 
+  ncells, 
+  nullable = FALSE, 
+  varnum = 1
+) {
+  stopifnot(
+    "Argument 'query' must be a tiledb_query object" = is(query, "tiledb_query"),
+    "Argument 'datatype' must be a character object" = is.character(datatype),
+    "Argument 'ncells' must be numeric" = is.numeric(ncells),
+    "Argument 'nullable' must be logical" = is.logical(nullable),
+    "Argument 'varnum' must be integer or numeric" = is.integer(varnum) || is.numeric(varnum)
+  )
   bufptr <- libtiledb_query_buffer_alloc_ptr(datatype, ncells, nullable, varnum)
   bufptr
 }
@@ -225,9 +253,11 @@ tiledb_query_buffer_alloc_ptr <- function(query, datatype, ncells, nullable=FALS
 #' @return An external pointer to the allocated buffer object
 #' @export
 tiledb_query_create_buffer_ptr <- function(query, datatype, object) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            #`Argument 'object' must be a vector` = is.vector(object),
-            `Argument 'datatype' must be a character object` = is.character(datatype))
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    # `Argument 'object' must be a vector` = is.vector(object),
+    `Argument 'datatype' must be a character object` = is.character(datatype)
+  )
   ncells <- length(object)
   bufptr <- libtiledb_query_buffer_alloc_ptr(datatype, ncells)
   bufptr <- libtiledb_query_buffer_assign_ptr(bufptr, datatype, object)
@@ -243,9 +273,11 @@ tiledb_query_create_buffer_ptr <- function(query, datatype, object) {
 #' @return The modified query object, invisibly
 #' @export
 tiledb_query_set_buffer_ptr <- function(query, attr, bufptr) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'attr' must be a character object` = is.character(attr),
-            `Argument 'bufptr' must be an external pointer` = is(bufptr, "externalptr"))
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'attr' must be a character object` = is.character(attr),
+    `Argument 'bufptr' must be an external pointer` = is(bufptr, "externalptr")
+  )
   libtiledb_query_set_buffer_ptr(query@ptr, attr, bufptr)
   invisible(query)
 }
@@ -270,7 +302,11 @@ tiledb_query_get_buffer_ptr <- function(bufptr) {
 #' @param sizestring An optional argument for the length of the internal string
 #' @return An R object as resulting from the query
 #' @export
-tiledb_query_get_buffer_char <- function(bufptr, sizeoffsets=0, sizestring=0) {
+tiledb_query_get_buffer_char <- function(
+  bufptr, 
+  sizeoffsets = 0,
+  sizestring = 0
+) {
   stopifnot(`Argument 'bufptr' must be an external pointer` = is(bufptr, "externalptr"))
   libtiledb_query_get_buffer_var_char(bufptr, sizeoffsets, sizestring)
 }
@@ -299,7 +335,7 @@ tiledb_query_submit <- function(query) {
 tiledb_query_submit_async <- function(query) {
   stopifnot("Argument 'query' must be a tiledb_query object" = is(query, "tiledb_query"))
   ## Deprecated April 2024, to be removed April 2025 or later
-  .Deprecated(msg="tiledb_query_submit_async() is deprecated, use tiledb_query_submit() instead.")
+  .Deprecated(msg = "tiledb_query_submit_async() is deprecated, use tiledb_query_submit() instead.")
   libtiledb_query_submit_async(query@ptr)
   invisible(query)
 }
@@ -345,8 +381,10 @@ tiledb_query_status <- function(query) {
 #' @seealso tiledb_query_result_buffer_elements_vec
 #' @export
 tiledb_query_result_buffer_elements <- function(query, attr) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'attr' must be a character object` = is.character(attr))
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'attr' must be a character object` = is.character(attr)
+  )
   libtiledb_query_result_buffer_elements(query@ptr, attr, 1) # request 2nd el in pair
 }
 
@@ -371,10 +409,16 @@ tiledb_query_result_buffer_elements <- function(query, attr) {
 #' buffer size.
 #' @seealso tiledb_query_result_buffer_elements
 #' @export
-tiledb_query_result_buffer_elements_vec <- function(query, attr, nullable = FALSE) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'attr' must be a character object` = is.character(attr),
-            `Argument 'nullable' must be a logical` = is.logical(nullable))
+tiledb_query_result_buffer_elements_vec <- function(
+  query, 
+  attr, 
+  nullable = FALSE
+) {
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'attr' must be a character object` = is.character(attr),
+    `Argument 'nullable' must be a logical` = is.logical(nullable)
+  )
   libtiledb_query_result_buffer_elements_vec(query@ptr, attr, nullable)
 }
 
@@ -388,17 +432,25 @@ tiledb_query_result_buffer_elements_vec <- function(query, attr, nullable = FALS
 #' @param stride An optional stride value for the range to be set
 #' @return The query object, invisibly
 #' @export
-tiledb_query_add_range <- function(query, schema, attr, lowval, highval, stride=NULL) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'schema' must be a tiledb_array_schema object` = is(schema, "tiledb_array_schema"),
-            `Argument 'attr' must be a character object` = is.character(attr),
-            `Argument 'lowval' must be numeric` = is.numeric(lowval),
-            `Argument 'highval' must be numeric` = is.numeric(highval),
-            `Argument 'stride' must be numeric (or NULL)` = is.null(stride) || is.numeric(lowval))
+tiledb_query_add_range <- function(
+  query, 
+  schema, 
+  attr, lowval, 
+  highval, 
+  stride = NULL
+) {
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'schema' must be a tiledb_array_schema object` = is(schema, "tiledb_array_schema"),
+    `Argument 'attr' must be a character object` = is.character(attr),
+    `Argument 'lowval' must be numeric` = is.numeric(lowval),
+    `Argument 'highval' must be numeric` = is.numeric(highval),
+    `Argument 'stride' must be numeric (or NULL)` = is.null(stride) || is.numeric(lowval)
+  )
   names <- tiledb_schema_get_names(schema)
   types <- tiledb_schema_get_types(schema)
   idx <- which(names == attr)
-  query <- tiledb_query_add_range_with_type(query, idx-1L, types[idx], lowval, highval, stride)
+  query <- tiledb_query_add_range_with_type(query, idx - 1L, types[idx], lowval, highval, stride)
   invisible(query)
 }
 
@@ -412,13 +464,22 @@ tiledb_query_add_range <- function(query, schema, attr, lowval, highval, stride=
 #' @param stride An optional stride value for the range to be set
 #' @return The query object, invisibly
 #' @export
-tiledb_query_add_range_with_type <- function(query, idx, datatype, lowval, highval, stride=NULL) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'idx' must be integer` = is.integer(idx),
-            `Argument 'datatype' must be character` = is.character(datatype),
-            `Argument 'lowval' must be numeric` = is.numeric(lowval),
-            `Argument 'highval' must be numeric` = is.numeric(highval),
-            `Argument 'stride' must be numeric (or NULL)` = is.null(stride) || is.numeric(lowval))
+tiledb_query_add_range_with_type <- function(
+  query, 
+  idx, 
+  datatype, 
+  lowval, 
+  highval, 
+  stride = NULL
+) {
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'idx' must be integer` = is.integer(idx),
+    `Argument 'datatype' must be character` = is.character(datatype),
+    `Argument 'lowval' must be numeric` = is.numeric(lowval),
+    `Argument 'highval' must be numeric` = is.numeric(highval),
+    `Argument 'stride' must be numeric (or NULL)` = is.null(stride) || is.numeric(lowval)
+  )
   ## The (initial) Query member function is deprecated, we now use a subarray
   sbrptr <- libtiledb_subarray(query@ptr)
   sbrptr <- libtiledb_subarray_add_range_with_type(sbrptr, idx, datatype, lowval, highval, stride)
@@ -446,8 +507,10 @@ tiledb_query_get_fragment_num <- function(query) {
 #' @return An character value with the fragment URI
 #' @export
 tiledb_query_get_fragment_uri <- function(query, idx) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'idx' must be numeric` = is.numeric(idx))
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'idx' must be numeric` = is.numeric(idx)
+  )
   libtiledb_query_get_fragment_uri(query@ptr, idx)
 }
 
@@ -460,8 +523,10 @@ tiledb_query_get_fragment_uri <- function(query, idx) {
 #' @return A two-element datetime vector with the start and end time of the fragment write.
 #' @export
 tiledb_query_get_fragment_timestamp_range <- function(query, idx) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'idx' must be numeric` = is.numeric(idx))
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'idx' must be numeric` = is.numeric(idx)
+  )
   libtiledb_query_get_fragment_timestamp_range(query@ptr, idx)
 }
 
@@ -478,8 +543,10 @@ tiledb_query_get_fragment_timestamp_range <- function(query, idx) {
 #' @return An estimate of the query result size
 #' @export
 tiledb_query_get_est_result_size <- function(query, name) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'name' must be character` = is.character(name))
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'name' must be character` = is.character(name)
+  )
   libtiledb_query_get_est_result_size(query@ptr, name)
 }
 
@@ -495,8 +562,10 @@ tiledb_query_get_est_result_size <- function(query, name) {
 #' @return An estimate of the query result size
 #' @export
 tiledb_query_get_est_result_size_var <- function(query, name) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'name' must be character` = is.character(name))
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'name' must be character` = is.character(name)
+  )
   libtiledb_query_get_est_result_size_var(query@ptr, name)
 }
 
@@ -508,9 +577,11 @@ tiledb_query_get_est_result_size_var <- function(query, name) {
 #' given dimensions
 #' @export
 tiledb_query_get_range_num <- function(query, idx) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'idx' must be numeric` = is.numeric(idx))
-  libtiledb_query_get_range_num(query@ptr, idx-1)
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'idx' must be numeric` = is.numeric(idx)
+  )
+  libtiledb_query_get_range_num(query@ptr, idx - 1)
 }
 
 #' Retrieve the query range for a query dimension and range index
@@ -522,10 +593,12 @@ tiledb_query_get_range_num <- function(query, idx) {
 #' range for the given dimension and range index
 #' @export
 tiledb_query_get_range <- function(query, dimidx, rngidx) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'dimidx' must be numeric` = is.numeric(dimidx),
-            `Argument 'rngidx' must be numeric` = is.numeric(rngidx))
-  libtiledb_query_get_range(query@ptr, dimidx-1, rngidx-1)
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'dimidx' must be numeric` = is.numeric(dimidx),
+    `Argument 'rngidx' must be numeric` = is.numeric(rngidx)
+  )
+  libtiledb_query_get_range(query@ptr, dimidx - 1, rngidx - 1)
 }
 
 #' Retrieve the query range for a variable-sized query dimension and range index
@@ -537,10 +610,12 @@ tiledb_query_get_range <- function(query, dimidx, rngidx) {
 #' range for the given dimension and range index
 #' @export
 tiledb_query_get_range_var <- function(query, dimidx, rngidx) {
-  stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-            `Argument 'dimidx' must be numeric` = is.numeric(dimidx),
-            `Argument 'rngidx' must be numeric` = is.numeric(rngidx))
-  libtiledb_query_get_range_var(query@ptr, dimidx-1, rngidx-1)
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'dimidx' must be numeric` = is.numeric(dimidx),
+    `Argument 'rngidx' must be numeric` = is.numeric(rngidx)
+  )
+  libtiledb_query_get_range_var(query@ptr, dimidx - 1, rngidx - 1)
 }
 
 #' Set a query combination object for a query
@@ -550,10 +625,12 @@ tiledb_query_get_range_var <- function(query, dimidx, rngidx) {
 #' @return The modified query object, invisibly
 #' @export
 tiledb_query_set_condition <- function(query, qc) {
-    stopifnot(`Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
-              `Argument 'qc' must be a query_condition object` = is(qc, "tiledb_query_condition"))
-    query@ptr <- libtiledb_query_set_condition(query@ptr, qc@ptr)
-    invisible(query)
+  stopifnot(
+    `Argument 'query' must be a tiledb_query object` = is(query, "tiledb_query"),
+    `Argument 'qc' must be a query_condition object` = is(qc, "tiledb_query_condition")
+  )
+  query@ptr <- libtiledb_query_set_condition(query@ptr, qc@ptr)
+  invisible(query)
 }
 
 #' Retrieve the cached status of the last finalized query
@@ -564,7 +641,7 @@ tiledb_query_set_condition <- function(query, qc) {
 #' @return The status of the last query
 #' @export
 tiledb_get_query_status <- function() {
-    .pkgenv[["query_status"]]
+  .pkgenv[["query_status"]]
 }
 
 #' Return query statistics as a JSON string
@@ -573,8 +650,8 @@ tiledb_get_query_status <- function() {
 #' @return A JSON-formatted string with context statistics
 #' @export
 tiledb_query_stats <- function(query) {
-    stopifnot(`The 'query' argument must be a TileDB Query object` = is(query, "tiledb_query"))
-    libtiledb_query_stats(query@ptr)
+  stopifnot(`The 'query' argument must be a TileDB Query object` = is(query, "tiledb_query"))
+  libtiledb_query_stats(query@ptr)
 }
 
 #' Return query context object
@@ -583,8 +660,8 @@ tiledb_query_stats <- function(query) {
 #' @return A TileDB Context object retrieved from the query
 #' @export
 tiledb_query_ctx <- function(query) {
-    stopifnot(`The 'query' argument must be a TileDB Query object` = is(query, "tiledb_query"))
-    new("tiledb_ctx", ptr = libtiledb_query_get_ctx(query@ptr))
+  stopifnot(`The 'query' argument must be a TileDB Query object` = is(query, "tiledb_query"))
+  new("tiledb_ctx", ptr = libtiledb_query_get_ctx(query@ptr))
 }
 
 ## The next function could be used to extract an 'tiledb_array' object from a query object
@@ -595,10 +672,10 @@ tiledb_query_ctx <- function(query) {
 # ' @param query A TileDB Query object
 # ' @return A TileDB Array object retrieved from the query
 # ' @ export
-#tiledb_query_array <- function(query) {
+# tiledb_query_array <- function(query) {
 #    stopifnot(`The 'query' must be a TileDB Query object` = is(query, "tiledb_query"))
 #    query@arr
-#}
+# }
 
 ##' Run an aggregate oprtation on the given query attribute
 ##'
@@ -608,14 +685,18 @@ tiledb_query_ctx <- function(query) {
 ##' @param nullable A boolean toggle whether the attribute is nullable
 ##' @return The value of the aggregation
 ##' @export
-tiledb_query_apply_aggregate <- function(query, attrname,
-                                         operation = c("Count", "NullCount", "Min", "Max",
-                                                       "Mean", "Sum"),
-                                         nullable = TRUE) {
-    stopifnot("The 'query' argument must be a TileDB Query object" = is(query, "tiledb_query"),
-              "The 'attrname' argument must be character" = is.character(attrname),
-              "The 'operation' argument must be character" = is.character(operation),
-              "The 'nullable' argument must be logical" = is.logical(nullable))
-    operation <- match.arg(operation)
-    libtiledb_query_apply_aggregate(query@ptr, attrname, operation, nullable)
+tiledb_query_apply_aggregate <- function(
+  query, 
+  attrname,
+  operation = c("Count", "NullCount", "Min", "Max", "Mean",  "Sum"),
+  nullable = TRUE
+) {
+  stopifnot(
+    "The 'query' argument must be a TileDB Query object" = is(query, "tiledb_query"),
+    "The 'attrname' argument must be character" = is.character(attrname),
+    "The 'operation' argument must be character" = is.character(operation),
+    "The 'nullable' argument must be logical" = is.logical(nullable)
+  )
+  operation <- match.arg(operation)
+  libtiledb_query_apply_aggregate(query@ptr, attrname, operation, nullable)
 }
